rm(list = ls())
Data <- read.csv("Testdata.csv", header=TRUE, sep=";")
head(Data)

####Check R == JASP: changing "missing = fiml" in R --> not the same####
fullmodel <- "# dependent regression
Y ~ b11*M + c11*X

# mediator regression
M ~ a11*X

# effect decomposition
# y1 ~ x1
ind_x1_m1_y1 := a11*b11
ind_x1_y1 := ind_x1_m1_y1
tot_x1_y1 := ind_x1_y1 + c11"
set.seed(1)
sem <- lavaan::sem(fullmodel, data = Data, missing = "fiml", se = "bootstrap",  bootstrap = 500)
lavaan::parameterEstimates(sem, 
                   se = TRUE, zstat = TRUE, pvalue = TRUE, ci = TRUE, 
                   standardized = TRUE, 
                   fmi = FALSE, level = 0.95, boot.ci.type = "bca.simple")

#output
#             lhs op           rhs        label   est    se     z pvalue ci.lower ci.upper std.lv std.all std.nox
# 1             Y  ~             M          b11 0.540 0.236 2.286  0.022   -0.031    0.992  0.540   0.349   0.349
# 2             Y  ~             X          c11 0.097 0.261 0.370  0.712   -0.396    0.616  0.097   0.058   0.069
# 3             M  ~             X          a11 0.529 0.132 4.013  0.000    0.277    0.806  0.529   0.490   0.583
# 4             Y ~~             Y              1.682 0.214 7.860  0.000    1.312    2.105  1.682   0.855   0.855
# 5             M ~~             M              0.627 0.144 4.358  0.000    0.390    0.999  0.627   0.760   0.760
# 6             X ~~             X              0.705 0.000    NA     NA    0.705    0.705  0.705   1.000   0.705
# 7             Y ~1                            1.678 0.444 3.779  0.000    0.834    2.588  1.678   1.196   1.196
# 8             M ~1                            0.821 0.237 3.467  0.001    0.298    1.254  0.821   0.904   0.904
# 9             X ~1                            2.061 0.000    NA     NA    2.061    2.061  2.061   2.454   2.061
# 10 ind_x1_m1_y1 :=       a11*b11 ind_x1_m1_y1 0.286 0.153 1.868  0.062    0.008    0.619  0.286   0.171   0.204
# 11    ind_x1_y1 :=  ind_x1_m1_y1    ind_x1_y1 0.286 0.153 1.868  0.062    0.008    0.619  0.286   0.171   0.204
# 12    tot_x1_y1 := ind_x1_y1+c11    tot_x1_y1 0.382 0.189 2.020  0.043   -0.002    0.735  0.382   0.229   0.273

#JASP OUTPUT
#           est     se      z       p       lower     upper
#Y ~ X:     0.068		0.141		0.487		0.626		-0.288		0.415	  <-> R: est: 0.097; p: 0.712
#indirect:  0.202		0.088		2.294		0.022		0.019		0.451     <-> R: est: 0.286; p: 0.062
#total:     0.271		0.123		2.207		0.027		0.014		0.518     <-> R: est: 0.382; p: 0.043

####Check R == JASP: changing exclude cases listwise in JASP --> not the same####
set.seed(1)
sem <- lavaan::sem(fullmodel, data = Data, se = "bootstrap",  bootstrap = 500)
lavaan::parameterEstimates(sem, 
                           se = TRUE, zstat = TRUE, pvalue = TRUE, ci = TRUE, 
                           standardized = TRUE, 
                           fmi = FALSE, level = 0.95, boot.ci.type = "bca.simple")

#             lhs op           rhs        label   est    se     z pvalue ci.lower ci.upper std.lv std.all std.nox
# 1            Y  ~             M          b11 0.507 0.217 2.341  0.019    0.088    0.979  0.507   0.343   0.343
# 2            Y  ~             X          c11 0.153 0.250 0.611  0.541   -0.408    0.597  0.153   0.098   0.111
# 3            M  ~             X          a11 0.524 0.133 3.945  0.000    0.283    0.830  0.524   0.496   0.564
# 4            Y ~~             Y              1.578 0.219 7.200  0.000    1.195    2.078  1.578   0.839   0.839
# 5            M ~~             M              0.650 0.146 4.453  0.000    0.411    1.014  0.650   0.754   0.754
# 6            X ~~             X              0.772 0.000    NA     NA    0.772    0.772  0.772   1.000   0.772
# 7 ind_x1_m1_y1 :=       a11*b11 ind_x1_m1_y1 0.266 0.142 1.873  0.061    0.043    0.603  0.266   0.170   0.194
# 8    ind_x1_y1 :=  ind_x1_m1_y1    ind_x1_y1 0.266 0.142 1.873  0.061    0.043    0.603  0.266   0.170   0.194
# 9    tot_x1_y1 := ind_x1_y1+c11    tot_x1_y1 0.419 0.210 1.992  0.046   -0.034    0.823  0.419   0.268   0.305

#JASP OUTPUT
#           est     se      z       p       lower     upper
#Y ~ X:     0.111		0.155		0.714		0.476		-0.280		0.483	  <-> R: est: 0.153; p: 0.541
#indirect:  0.192		0.088		2.172		0.030		0.007		0.448     <-> R: est: 0.266; p: 0.061
#total:     0.303		0.141		2.140		0.032		0.007		0.585     <-> R: est: 0.419; p: 0.046

